@@ -18,6 +18,7 @@
 
 #include <unistd.h>
 #include <errno.h>
+#include <sys/stat.h>
 
 #include <glib.h>
 #include <glib/gprintf.h>
@@ -32,7 +33,8 @@ STATIC gboolean
 write_ovs_systemd_unit(const char* id, const GString* cmds, const char* rootdir, gboolean physical, gboolean cleanup, const char* dependency, GError** error)
 {
     g_autofree char* escaped_netdef_id = g_uri_escape_string(id, NULL, TRUE);
-    g_autofree char* link = g_strjoin(NULL, rootdir ?: "", "/run/systemd/system/systemd-networkd.service.wants/netplan-ovs-", escaped_netdef_id, ".service", NULL);
+    g_autofree char* link = g_strjoin(NULL, rootdir != NULL ? rootdir : "",
+                                      "/run/systemd/system/systemd-networkd.service.wants/netplan-ovs-", escaped_netdef_id, ".service", NULL);
     g_autofree char* path = g_strjoin(NULL, "/run/systemd/system/netplan-ovs-", escaped_netdef_id, ".service", NULL);
 
     GString* s = g_string_new("[Unit]\n");
@@ -69,7 +71,9 @@ write_ovs_systemd_unit(const char* id, const GString* cmds, const char* rootdir,
     g_autofree char* new_s = _netplan_scrub_systemd_unit_contents(s->str);
     g_string_free(s, TRUE);
     s = g_string_new(new_s);
-    _netplan_g_string_free_to_file_with_permissions(s, rootdir, path, NULL, "root", "root", 0640);
+    mode_t orig_umask = umask(022);
+    _netplan_g_string_free_to_file(s, rootdir, path, NULL);
+    umask(orig_umask);
 
     _netplan_safe_mkdir_p_dir(link);
     if (symlink(path, link) < 0 && errno != EEXIST) {
@@ -118,8 +122,8 @@ netplan_type_is_physical(const NetplanDefType type)
 STATIC void
 write_ovs_tag_setting(const gchar* id, const char* type, const char* col, const char* key, const char* value, GString* cmds)
 {
-    g_assert(col);
-    g_assert(value);
+    g_assert(col != NULL);
+    g_assert(value != NULL);
     g_autofree char *clean_value = g_strdup(value);
     /* Replace " " -> "," if value contains spaces */
     if (strchr(value, ' ')) {
@@ -133,7 +137,7 @@ write_ovs_tag_setting(const gchar* id, const char* type, const char* col, const
     g_string_append_printf(s, "%s", col);
     if (key)
         g_string_append_printf(s, "/%s", key);
-    g_string_append_printf(s, "=%s", clean_value);
+    g_string_append_printf(s, "=\"%s\"", clean_value);
     append_systemd_cmd(cmds, OPENVSWITCH_OVS_VSCTL " set %s %s %s", type, id, s->str);
     g_string_free(s, TRUE);
 }
@@ -149,7 +153,7 @@ write_ovs_additional_data(GHashTable *data, const char* type, const gchar* id, G
     while (g_hash_table_iter_next(&iter, (gpointer) &key, (gpointer) &value)) {
         /* XXX: we need to check what happens when an invalid key=value pair
             gets supplied here. We might want to handle this somehow. */
-        append_systemd_cmd(cmds, OPENVSWITCH_OVS_VSCTL " set %s %s %s:%s=%s",
+        append_systemd_cmd(cmds, OPENVSWITCH_OVS_VSCTL " set %s %s %s:%s=\"%s\"",
                            type, id, setting, key, value);
         write_ovs_tag_setting(id, type, setting, key, value, cmds);
     }
@@ -209,7 +213,7 @@ STATIC void
 write_ovs_tag_netplan(const gchar* id, const char* type, GString* cmds)
 {
     /* Mark this bridge/port/interface as created by netplan */
-    append_systemd_cmd(cmds, OPENVSWITCH_OVS_VSCTL " set %s %s external-ids:netplan=true",
+    append_systemd_cmd(cmds, OPENVSWITCH_OVS_VSCTL " set %s %s external-ids:netplan=\"true\"",
                        type, id);
 }
 
@@ -260,7 +264,7 @@ write_ovs_bridge_interfaces(const NetplanState* np_state, const NetplanNetDefini
 STATIC void
 write_ovs_protocols(const NetplanOVSSettings* ovs_settings, const gchar* bridge, GString* cmds)
 {
-    g_assert(bridge);
+    g_assert(bridge != NULL);
     GString* s = g_string_new(g_array_index(ovs_settings->protocols, char*, 0));
 
     for (unsigned i = 1; i < ovs_settings->protocols->len; ++i)
@@ -306,7 +310,8 @@ write_ovs_bridge_controller_targets(const NetplanOVSSettings* settings, const Ne
             }
         g_string_append_printf(s, "%s ", target);
     }
-    g_string_erase(s, s->len-1, 1);
+    g_assert(s->len < G_MAXSSIZE);
+    g_string_erase(s, (gssize)s->len-1, 1);
 
     append_systemd_cmd(cmds, OPENVSWITCH_OVS_VSCTL " set-controller %s %s", bridge, s->str);
     write_ovs_tag_setting(bridge, "Bridge", "global", "set-controller", s->str, cmds);
@@ -389,7 +394,7 @@ _netplan_netdef_write_ovs(const NetplanState* np_state, const NetplanNetDefiniti
                 break;
 
             case NETPLAN_DEF_TYPE_PORT:
-                g_assert(def->peer);
+                g_assert(def->peer != NULL);
                 dependency = def->bridge?: def->bond;
                 if (!dependency) {
                     g_set_error(error, NETPLAN_BACKEND_ERROR, NETPLAN_ERROR_VALIDATION, "%s: OpenVSwitch patch port needs to be assigned to a bridge/bond\n", def->id);
@@ -405,7 +410,7 @@ _netplan_netdef_write_ovs(const NetplanState* np_state, const NetplanNetDefiniti
                 break;
 
             case NETPLAN_DEF_TYPE_VLAN:
-                g_assert(def->vlan_link);
+                g_assert(def->vlan_link != NULL);
                 dependency = def->vlan_link->id;
                 /* Create a fake VLAN bridge */
                 append_systemd_cmd(cmds, OPENVSWITCH_OVS_VSCTL " --may-exist add-br %s %s %i", def->id, def->vlan_link->id, def->vlan_id)
