@@ -18,6 +18,7 @@
 
 #include <unistd.h>
 #include <errno.h>
+#include <sys/stat.h>
 
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -30,7 +31,8 @@ STATIC gboolean
 write_sriov_rebind_systemd_unit(GHashTable* pfs, const char* rootdir, GError** error)
 {
     g_autofree gchar* id_escaped = NULL;
-    g_autofree char* link = g_strjoin(NULL, rootdir ?: "", "/run/systemd/system/multi-user.target.wants/netplan-sriov-rebind.service", NULL);
+    g_autofree char* link = g_strjoin(NULL, rootdir != NULL ? rootdir : "",
+                                      "/run/systemd/system/multi-user.target.wants/netplan-sriov-rebind.service", NULL);
     g_autofree char* path = g_strjoin(NULL, "/run/systemd/system/netplan-sriov-rebind.service", NULL);
 
     GHashTableIter iter;
@@ -57,7 +59,9 @@ write_sriov_rebind_systemd_unit(GHashTable* pfs, const char* rootdir, GError** e
     g_autofree char* new_s = _netplan_scrub_systemd_unit_contents(s->str);
     g_string_free(s, TRUE);
     s = g_string_new(new_s);
-    _netplan_g_string_free_to_file_with_permissions(s, rootdir, path, NULL, "root", "root", 0640);
+    mode_t orig_umask = umask(022);
+    _netplan_g_string_free_to_file(s, rootdir, path, NULL);
+    umask(orig_umask);
     g_string_free(interfaces, TRUE);
 
     _netplan_safe_mkdir_p_dir(link);
@@ -75,7 +79,8 @@ STATIC gboolean
 write_sriov_apply_systemd_unit(GHashTable* pfs, const char* rootdir, GError** error)
 {
     g_autofree gchar* id_escaped = NULL;
-    g_autofree char* link = g_strjoin(NULL, rootdir ?: "", "/run/systemd/system/multi-user.target.wants/netplan-sriov-apply.service", NULL);
+    g_autofree char* link = g_strjoin(NULL, rootdir != NULL ? rootdir : "",
+                                      "/run/systemd/system/multi-user.target.wants/netplan-sriov-apply.service", NULL);
     g_autofree char* path = g_strjoin(NULL, "/run/systemd/system/netplan-sriov-apply.service", NULL);
     GHashTableIter iter;
     gpointer key;
@@ -96,7 +101,9 @@ write_sriov_apply_systemd_unit(GHashTable* pfs, const char* rootdir, GError** er
     g_autofree char* new_s = _netplan_scrub_systemd_unit_contents(s->str);
     g_string_free(s, TRUE);
     s = g_string_new(new_s);
-    _netplan_g_string_free_to_file_with_permissions(s, rootdir, path, NULL, "root", "root", 0640);
+    mode_t orig_umask = umask(022);
+    _netplan_g_string_free_to_file(s, rootdir, path, NULL);
+    umask(orig_umask);
 
     _netplan_safe_mkdir_p_dir(link);
     if (symlink(path, link) < 0 && errno != EEXIST) {
@@ -220,5 +227,12 @@ _netplan_state_get_vf_count_for_def(const NetplanState* np_state, const NetplanN
         g_set_error(error, NETPLAN_BACKEND_ERROR, NETPLAN_ERROR_VALIDATION, "more VFs allocated than the explicit size declared: %d > %d", count, netdef->sriov_explicit_vf_count);
         return -1;
     }
-    return netdef->sriov_explicit_vf_count != G_MAXUINT ? netdef->sriov_explicit_vf_count : count;
+
+    if (netdef->sriov_explicit_vf_count != G_MAXUINT) {
+        g_assert(netdef->sriov_explicit_vf_count <= G_MAXINT);
+        count = netdef->sriov_explicit_vf_count;
+    }
+
+    g_assert(count <= G_MAXINT);
+    return (int)count;
 }
