@@ -21,19 +21,21 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import os
-import sys
-import re
-import time
-import subprocess
-import tempfile
-import unittest
-import shutil
-import gi
 import glob
-import json
-import pwd
 import grp
+import ipaddress
+import json
+import os
+import pwd
+import re
+import shutil
+import subprocess
+import sys
+import tempfile
+import time
+import unittest
+
+import gi
 
 # make sure we point to libnetplan properly.
 os.environ.update({'LD_LIBRARY_PATH': '.:{}'.format(os.environ.get('LD_LIBRARY_PATH'))})
@@ -52,6 +54,23 @@ def resolved_in_use():
     return os.path.isfile('/run/systemd/resolve/resolv.conf')
 
 
+def mac_to_eui64(hwaddr: str) -> ipaddress.IPv6Address:
+    '''
+    Calculate a EUI-64 IPv6 address from a MAC, according to RFC-4291,
+    e.g.: https://www.geeksforgeeks.org/ipv6-eui-64-extended-unique-identifier
+    '''
+    # convert MAC address bytes to a list of base10 decimals
+    mac_addr = [int(h, base=16) for h in hwaddr.split(':')]
+    mac_addr[0] ^= 2  # flip 7th bit of the 1st byte, e.g. XOR 0b00000010 (=2)
+    # inject 0xFFFE in the middle, increasing 48bit MAC to 64bit IPv6 Interface ID
+    mac_addr[3:3] = [0xff, 0xfe]
+    # apply 64bit IPv6 Interface ID on generic IPv6 carrier address (2600::)
+    eui_addr_int = 0x26000000000000000000000000000000
+    for i, h in enumerate(reversed(mac_addr)):
+        eui_addr_int |= h << 8 * i
+    return ipaddress.IPv6Address(eui_addr_int)
+
+
 class IntegrationTestsBase(unittest.TestCase):
     '''Common functionality for network test cases
 
@@ -387,7 +406,7 @@ class IntegrationTestsBase(unittest.TestCase):
         nd_expected_owner = 'root'
         nd_expected_group = 'systemd-network'
 
-        sd_expected_mode = 0o100640
+        sd_expected_mode = 0o100644
         sd_expected_owner = 'root'
         sd_expected_group = 'root'
 
