@@ -22,6 +22,7 @@ import tempfile
 import unittest
 
 from netplan_cli.configmanager import ConfigManager, ConfigurationError
+from netplan_cli.cli.ovs import OPENVSWITCH_OVS_VSCTL
 
 
 class TestConfigManager(unittest.TestCase):
@@ -229,6 +230,8 @@ class TestConfigManager(unittest.TestCase):
         self.assertIn('eth0',    state.ethernets)
         self.assertIn('eth42',   state.ethernets)
 
+    @unittest.skipIf(not os.path.exists(OPENVSWITCH_OVS_VSCTL),
+                     'OpenVSwitch not installed')
     def test_parse_merging_ovs(self):
         state = self.configmanager.parse(extra_config=[os.path.join(self.workdir.name, "ovs_merging.yaml")])
         self.assertIn('eth0',   state.ethernets)
