@@ -34,6 +34,7 @@ from netplan_cli.cli.ovs import OPENVSWITCH_OVS_VSCTL
 
 import netplan
 from netplan.netdef import NetplanRoute
+from netplan.parser import Flags
 
 # We still need direct (ctypes) access to libnetplan.so to test certain cases
 # that are not covered by the 'netplan' module bindings
@@ -288,7 +289,11 @@ class TestNetdefRouteIterator(TestBase):
           mtu: 1500
           congestion-window: 123
           advertised-receive-window: 321
-          from: 192.168.0.0/24''')
+          from: 192.168.0.0/24
+        - to: 4.5.6.7/32
+          via: 1.2.3.4
+          on-link: true
+          advertised-mss: 1400''')
 
         netdef = next(netplan.netdef.NetDefinitionIterator(state, "ethernets"))
         routes = [route for route in netdef.routes]
@@ -299,6 +304,8 @@ class TestNetdefRouteIterator(TestBase):
                              routes[2].onlink, routes[2].type, routes[2].scope, routes[2].mtubytes, routes[2].congestion_window,
                              routes[2].advertised_receive_window},
                             {'3.2.1.0/24', '10.20.30.40', 1000, 1000, True, 'local', 'host', 1500, 123, 321, '192.168.0.0/24'})
+        self.assertSetEqual({routes[3].to, routes[3].via, routes[3].onlink, routes[3].advertised_mss},
+                            {'4.5.6.7/32', '1.2.3.4', True, 1400})
 
 
 class TestRoute(TestBase):
@@ -369,6 +376,82 @@ class TestParser(TestBase):
                 parser.load_yaml(f)
             self.assertIn('Invalid YAML', str(context.exception))
 
+    def test_load_yaml_with_bad_definition_and_ignore_error(self):
+        ''' Test that the parser will not fail when the parser flag is set '''
+        parser = netplan.Parser()
+        parser.flags |= Flags.IGNORE_ERRORS
+        with tempfile.NamedTemporaryFile() as f:
+            f.write(b'''network:
+  ethernets:
+    eth0:
+      dhcp4: false
+    eth1:
+      dhcp4: 1
+    eth2:
+      dhcp4: true''')
+            f.seek(0, io.SEEK_SET)
+            parser.load_yaml(f.name)
+
+            state = netplan.State()
+            state.import_parser_results(parser)
+            self.assertFalse(state.ethernets.get('eth0').dhcp4)
+            # eth1 parsing failed so the default value of dhcp4 was kept
+            self.assertFalse(state.ethernets.get('eth1').dhcp4)
+            self.assertTrue(state.ethernets.get('eth2').dhcp4)
+
+    def test_load_yaml_with_bad_definition_ignore_errors_and_check_error_count(self):
+        ''' Test that error counter contains the expect number of errors '''
+        parser = netplan.Parser()
+        parser.flags |= Flags.IGNORE_ERRORS
+        with tempfile.NamedTemporaryFile() as f:
+            f.write(b'''network:
+  bonds:
+    bond0:
+      interfaces:
+        - missingeth0
+  bridges:
+    br0:
+      addresses:
+        - 192.168.0.1
+  ethernets:
+    eth0:
+      dhcp4: false
+    eth1:
+      dhcp4: 1
+    eth2:
+      dhcp4: true''')
+            f.seek(0, io.SEEK_SET)
+            parser.load_yaml(f.name)
+            self.assertEqual(parser.error_count, 3)
+
+    def test_load_hierarchy_with_bad_yaml_and_ignore_error(self):
+        ''' Test that the parser will not fail when the parser flag is set '''
+        parser = netplan.Parser()
+        parser.flags |= Flags.IGNORE_ERRORS
+        with tempfile.TemporaryDirectory() as d:
+            full_dir = d + '/etc/netplan'
+            os.makedirs(full_dir)
+            with (tempfile.NamedTemporaryFile(suffix='.yaml', dir=full_dir) as f1,
+                  tempfile.NamedTemporaryFile(suffix='.yaml', dir=full_dir) as f2):
+                f1.write(b'''network:
+  ethernets:
+    eth0: {}''')
+                f1.flush()
+
+                f2.write(b''':''')
+                f2.flush()
+
+                parser.load_yaml_hierarchy(d)
+
+                state = netplan.State()
+                state.import_parser_results(parser)
+                self.assertIn('eth0', state.ethernets)
+
+    def test_parser_flags_set_bad_flags(self):
+        parser = netplan.Parser()
+        with self.assertRaises(netplan.NetplanParserFlagsException):
+            parser.flags = 1 << 24
+
     def test_load_keyfile(self):
         parser = netplan.Parser()
         state = netplan.State()
@@ -841,6 +924,20 @@ class TestNetDefinition(TestBase):
         self.assertNotIn('ipv4', state['eth0'].link_local)
         self.assertIn('ipv6', state['eth0'].link_local)
 
+    def test_get_accept_ra(self):
+        state = state_from_yaml(self.confdir, '''network:
+  ethernets:
+    eth0:
+      accept-ra: false
+    eth1:
+      accept-ra: true
+    eth2: {}
+      ''')
+
+        self.assertFalse(state['eth0'].accept_ra)
+        self.assertTrue(state['eth1'].accept_ra)
+        self.assertIsNone(state['eth2'].accept_ra)
+
     def test_get_macaddress(self):
         state = state_from_yaml(self.confdir, '''network:
   ethernets:
@@ -850,6 +947,24 @@ class TestNetDefinition(TestBase):
 
         self.assertEqual(state['eth0'].macaddress, 'aa:bb:cc:dd:ee:ff')
 
+    def test_get_gateway4(self):
+        state = state_from_yaml(self.confdir, '''network:
+  ethernets:
+    eth0:
+      gateway4: 192.168.0.254
+      ''')
+
+        self.assertEqual(state['eth0']._gateway4, '192.168.0.254')
+
+    def test_get_gateway6(self):
+        state = state_from_yaml(self.confdir, '''network:
+  ethernets:
+    eth0:
+      gateway6: abcd::1234
+      ''')
+
+        self.assertEqual(state['eth0']._gateway6, 'abcd::1234')
+
         state = state_from_yaml(self.confdir, '''network:
   ethernets:
     eth0: {}''')
